@@ -2,4 +2,6 @@
 """Random Effects models."""
 from .effect_base import EffectBase
 from .effect_blank import EffectBlank
-from .effect_static import EffectStatic
\ No newline at end of file
+from .effect_static import EffectStatic
+from .effect_free import EffectFree
+from .effect_ma import EffectMA
\ No newline at end of file
